@@ -2,10 +2,14 @@
 import pathlib
 import sys
 
-DEBPUTY_ROOT_DIR = pathlib.Path(__file__).parent  # TODO: Subst during install
+# Replaced during install; must be a single line
+# fmt: off
+DEBPUTY_ROOT_DIR = pathlib.Path(__file__).parent
+# fmt: on
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # setup PYTHONPATH: add our installation directory.
     sys.path.insert(0, str(DEBPUTY_ROOT_DIR))
     from debputy.commands.deb_materialization import main
+
     main()
