@@ -17,7 +17,6 @@ from typing import (
 )
 from collections.abc import Sequence
 
-from debputy import DEBPUTY_ROOT_DIR, DEBPUTY_PLUGIN_ROOT_DIR
 from debputy.analysis import REFERENCE_DATA_TABLE
 from debputy.build_support import perform_clean, perform_builds
 from debputy.commands.debputy_cmd.context import (
@@ -62,7 +61,7 @@ except ImportError:
         pass
 
 
-from debputy.version import __version__
+from debputy.version import DEBPUTY_ROOT_DIR, DEBPUTY_PLUGIN_ROOT_DIR, version
 from debputy.filesystem_scan import (
     OSFSROOverlay,
     FSRootDir,
@@ -323,7 +322,7 @@ def parse_args() -> argparse.Namespace:
         prog=program_name(),
     )
 
-    parser.add_argument("--version", action="version", version=__version__)
+    parser.add_argument("--version", action="version", version=version())
 
     _add_common_args(parser)
     from debputy.commands.debputy_cmd.plugin_cmds import (
@@ -802,11 +801,12 @@ def _dpkg_build_driver_integration(context: CommandContext) -> None:
             _info(f"Loaded plugin {plugin.plugin_name}")
     if task_name == "clean":
         perform_clean(context, manifest)
-    elif task_name in ("build", "build-indep", "build-arch"):
-        perform_builds(context, manifest)
+        return
+    build_system_install_dirs = list[tuple[str, frozenset[BinaryPackage]]]()
+    perform_builds(context, manifest, build_system_install_dirs)
+    if task_name in ("build", "build-indep", "build-arch"):
+        return
     elif task_name in ("binary", "binary-indep", "binary-arch"):
-        build_system_install_dirs: list[tuple[str, frozenset[BinaryPackage]]] = []
-        perform_builds(context, manifest, build_system_install_dirs)
         assemble(
             context,
             manifest,
@@ -983,7 +983,7 @@ def _supports_tool_command(context: CommandContext) -> None:
     ],
 )
 def _export_reference_data(context: CommandContext) -> None:
-    dataset_name = context.parsed_args.dataset
+    dataset_name: str = context.parsed_args.dataset
     output_format = context.parsed_args.output_format
     if dataset_name is not None:
         subdata_set = REFERENCE_DATA_TABLE.get(dataset_name)
