@@ -416,7 +416,7 @@ def fixup_debian_changelog_and_news_file(
     elif is_native:
         changelog = doc_dir.get("changelog")
 
-    trim = False if "notrimdch" in build_env.deb_build_options else True
+    trim = "notrimdch" not in build_env.deb_build_options
 
     kept_entries = None
     pruned_changelog = False
@@ -1318,7 +1318,7 @@ def compute_installed_size(fs_root: VirtualPath) -> int:
     for path in fs_root.all_paths():
         if path.is_symlink or path.is_file:
             try:
-                st = path.stat()
+                st = os.stat(path.fs_path)
                 if st.st_nlink > 1:
                     hl_key = (st.st_dev, st.st_ino)
                     if hl_key in hard_links:
