@@ -10,6 +10,7 @@ import stat
 import subprocess
 import tempfile
 import time
+import typing
 from abc import ABC
 from contextlib import suppress
 from typing import (
@@ -304,6 +305,32 @@ class CurrentPluginContextManager:
 class VirtualPathBase(VirtualPath, ABC):
     __slots__ = ()
 
+    def stat(self) -> os.stat_result:
+        # TODO: Remove
+        """Attempt to do stat of the underlying path (if it exists)
+
+        *Avoid* using `stat()` whenever possible where a more specialized attribute exist.  The
+        `stat()` call returns the data from the file system and often, `debputy` does *not* track
+        its state in the file system.  As an example, if you want to know the file system mode of
+        a path, please use the `mode` attribute instead.
+
+        This never follow symlinks (it behaves like `os.lstat`). It will raise an error
+        if the path is not backed by a file system object (that is, `has_fs_path` is False).
+
+        :return: The stat result or an error.
+        """
+        raise NotImplementedError()
+
+    @property
+    def size(self) -> int:
+        """Resolve the file size (`st_size`)
+
+        This may be using `stat()` and therefore `fs_path`.
+
+        :return: The size of the file in bytes
+        """
+        return self.stat().st_size
+
     def _orphan_safe_path(self) -> str:
         return self.path
 
@@ -425,7 +452,7 @@ class VirtualPathBase(VirtualPath, ABC):
     def open_child(
         self,
         name: str,
-        mode: TextOpenMode = ...,
+        mode: TextOpenMode = "r",
         buffering: int = -1,
     ) -> TextIO: ...
 
@@ -433,25 +460,12 @@ class VirtualPathBase(VirtualPath, ABC):
     def open_child(
         self,
         name: str,
-        mode: BinaryOpenMode = ...,
+        mode: BinaryOpenMode,
         buffering: int = -1,
     ) -> BinaryIO: ...
 
-    @overload
-    def open_child(
-        self,
-        name: str,
-        mode: OpenMode = ...,
-        buffering: int = -1,
-    ) -> TextIO | BinaryIO: ...
-
     @contextlib.contextmanager
-    def open_child(
-        self,
-        name: str,
-        mode: OpenMode = "r",
-        buffering: int = -1,
-    ) -> TextIO | BinaryIO:
+    def open_child(self, name, mode="r", buffering=-1):
         """Open a child path of the current directory in a given mode. Usually used with a context manager
 
         The path is opened according to the `mode` parameter similar to the built-in `open` in Python.
@@ -484,8 +498,13 @@ class VirtualPathBase(VirtualPath, ABC):
                     f"Path {self.path}/{name} does not exist and mode had `r`"
                 )
             if "+" not in mode:
-                with existing.open(byte_io="b" in mode, buffering=buffering) as fd:
-                    yield fd
+                # open(byte_io="b" in mode) matches no typed signature overload.
+                if "b" in mode:
+                    with existing.open(byte_io=True, buffering=buffering) as fd:
+                        yield fd
+                else:
+                    with existing.open(byte_io=False, buffering=buffering) as fd:
+                        yield fd
 
         encoding = None if "b" in mode else "utf-8"
 
@@ -809,11 +828,14 @@ class FSPath(VirtualPathBase, ABC):
                 os.chmod(fs_path, new_fs_mode)
             self.mode |= min_bit
 
+    def _resolve_initial_mtime(self) -> float:
+        return self.stat().st_mtime
+
     @property
     def mtime(self) -> float:
         mtime = self._mtime
         if mtime is None:
-            mtime = self.stat().st_mtime
+            mtime = self._resolve_initial_mtime()
             self._mtime = mtime
         return mtime
 
@@ -1154,13 +1176,8 @@ class VirtualFSPathBase(FSPath, ABC):
             stat_cache=stat_cache,
         )
 
-    @property
-    def mtime(self) -> float:
-        mtime = self._mtime
-        if mtime is None:
-            mtime = time.time()
-            self._mtime = mtime
-        return mtime
+    def _resolve_initial_mtime(self) -> float:
+        return time.time()
 
     @property
     def has_fs_path(self) -> bool:
@@ -1308,22 +1325,11 @@ class VirtualPathWithReference(VirtualFSPathBase, ABC):
         ref_path = self._reference_path
         return ref_path is not None and ref_path.has_fs_path
 
-    @property
-    def mtime(self) -> float:
-        mtime = self._mtime
-        if mtime is None:
-            ref_path = self._reference_path
-            if ref_path:
-                mtime = ref_path.mtime
-            else:
-                mtime = super().mtime
-            self._mtime = mtime
-        return mtime
-
-    @mtime.setter
-    def mtime(self, new_mtime: float) -> None:
-        self._rw_check()
-        self._mtime = new_mtime
+    def _resolve_initial_mtime(self) -> float:
+        ref_path = self._reference_path
+        if ref_path:
+            return ref_path.mtime
+        return super()._resolve_initial_mtime()
 
     @property
     def fs_path(self) -> str:
@@ -1339,15 +1345,26 @@ class VirtualPathWithReference(VirtualFSPathBase, ABC):
         if ref_path is not None and (
             not super().has_fs_path or super().fs_path == ref_path.fs_path
         ):
-            return ref_path.stat()
+            return typing.cast(VirtualPathBase, ref_path).stat()
         return super().stat()
 
+    @overload
     def open(
         self,
         *,
-        byte_io: bool = False,
+        byte_io: Literal[False] = False,
         buffering: int = -1,
-    ) -> TextIO | BinaryIO:
+    ) -> TextIO: ...
+
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: int = -1,
+    ) -> BinaryIO: ...
+
+    def open(self, *, byte_io=False, buffering=-1):
         reference_path = self._reference_path
         if reference_path is not None and reference_path.fs_path == self.fs_path:
             return reference_path.open(byte_io=byte_io, buffering=buffering)
@@ -1571,16 +1588,8 @@ class VirtualTestPath(FSPath):
         assert link_target is not None
         return link_target
 
-    @property
-    def mtime(self) -> float:
-        if self._mtime is None:
-            self._mtime = time.time()
-        return self._mtime
-
-    @mtime.setter
-    def mtime(self, new_mtime: float) -> None:
-        self._rw_check()
-        self._mtime = new_mtime
+    def _resolve_initial_mtime(self) -> float:
+        return time.time()
 
     @property
     def has_fs_path(self) -> bool:
@@ -1657,13 +1666,24 @@ class VirtualTestPath(FSPath):
             )
         return super().replace_fs_path_content(use_fs_path_mode=use_fs_path_mode)
 
-    @contextlib.contextmanager
+    @overload
     def open_child(
         self,
         name: str,
-        mode: OpenMode = "r",
+        mode: TextOpenMode = "r",
         buffering: int = -1,
-    ) -> TextIO | BinaryIO:
+    ) -> TextIO: ...
+
+    @overload
+    def open_child(
+        self,
+        name: str,
+        mode: BinaryOpenMode,
+        buffering: int = -1,
+    ) -> BinaryIO: ...
+
+    @contextlib.contextmanager
+    def open_child(self, name, mode="r", buffering=-1):
         existing = self.get(name)
         if existing or "r" in mode:
             with super().open_child(name, mode, buffering=buffering) as fd:
@@ -1685,12 +1705,23 @@ class VirtualTestPath(FSPath):
             has_fs_path=True,
         )
 
+    @overload
     def open(
         self,
         *,
-        byte_io: bool = False,
+        byte_io: Literal[False] = False,
         buffering: int = -1,
-    ) -> TextIO | BinaryIO:
+    ) -> TextIO: ...
+
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: int = -1,
+    ) -> BinaryIO: ...
+
+    def open(self, *, byte_io=False, buffering=-1):
         if self._content is None:
             try:
                 return super().open(byte_io=byte_io, buffering=buffering)
@@ -1785,12 +1816,23 @@ class OSFSOverlayBase(VirtualPathBase, Generic[FSP]):
     def has_fs_path(self) -> bool:
         return True
 
+    @overload
     def open(
         self,
         *,
-        byte_io: bool = False,
+        byte_io: Literal[False] = False,
         buffering: int = -1,
-    ) -> TextIO | BinaryIO:
+    ) -> TextIO: ...
+
+    @overload
+    def open(
+        self,
+        *,
+        byte_io: Literal[True],
+        buffering: int = -1,
+    ) -> BinaryIO: ...
+
+    def open(self, *, byte_io=False, buffering=-1):
         # Allow symlinks for open here, because we can let the OS resolve the symlink reliably in this
         # case.
         if not self.is_file and not self.is_symlink:
