@@ -3,18 +3,7 @@ import dataclasses
 import os.path
 import re
 from enum import IntEnum
-from typing import (
-    List,
-    Dict,
-    FrozenSet,
-    Union,
-    Tuple,
-    Set,
-    Optional,
-    TYPE_CHECKING,
-    cast,
-    Any,
-)
+from typing import TYPE_CHECKING, cast, Any
 from collections.abc import Callable, Iterator, Sequence, Iterable, Mapping
 
 from debputy.exceptions import DebputyRuntimeError
@@ -63,7 +52,7 @@ class PathAlreadyInstalledOrDiscardedError(InstallRuleError):
 
     @property
     def into(self) -> frozenset[BinaryPackage]:
-        return cast("FrozenSet[BinaryPackage]", self.args[1])
+        return cast(frozenset[BinaryPackage], self.args[1])
 
     @property
     def definition_source(self) -> str:
@@ -401,7 +390,7 @@ class SourcePathMatcher:
         matched = []
         already_installed_paths = 0
         already_excluded_paths = 0
-        glob_expand = False if isinstance(match_rule, ExactFileSystemPath) else True
+        glob_expand = not isinstance(match_rule, ExactFileSystemPath)
 
         for match in _resolve_path(
             match_rule,
@@ -590,20 +579,17 @@ class InstallRule(DebputyDispatchableType):
     def _check_single_match(
         self, source: FileSystemMatchRule, matches: list[PathMatch]
     ) -> None:
-        seen_pkgs = set()
-        problem_pkgs = frozenset()
+        seen_pkgs = set[BinaryPackage]()
         for m in matches:
             problem_pkgs = seen_pkgs & m.into
             if problem_pkgs:
-                break
-            seen_pkgs.update(problem_pkgs)
-        if problem_pkgs:
-            pkg_names = ", ".join(sorted(p.name for p in problem_pkgs))
-            _error(
-                f'The pattern "{source.raw_match_rule}" matched multiple entries for the packages: {pkg_names}.'
-                "However, it should matched exactly one item. Please tighten the pattern defined"
-                f" in {self._definition_source}"
-            )
+                pkg_names = ", ".join(sorted(p.name for p in problem_pkgs))
+                _error(
+                    f'The pattern "{source.raw_match_rule}" matched multiple entries for the packages: {pkg_names}.'
+                    " However, it should match exactly one item. Please tighten the pattern defined"
+                    f" in {self._definition_source}."
+                )
+            seen_pkgs.update(m.into)
 
     def _match_pattern(
         self,
@@ -1172,7 +1158,6 @@ class DiscardRule(InstallRule):
         install_context: InstallRuleContext,
         condition_context: ConditionContext,
     ) -> None:
-        into = frozenset()
         limit_to = self._limit_to
         if limit_to:
             matches = {x.match_rule.path for x in limit_to}
@@ -1199,5 +1184,5 @@ class DiscardRule(InstallRule):
                 fs_match_rule,
                 condition_context,
                 search_dirs,
-                into,
+                into=frozenset(),
             )
