@@ -1,34 +1,28 @@
 import collections
 import dataclasses
 import typing
+from types import UnionType
 from typing import (
     Any,
-    Callable,
-    Tuple,
     TypedDict,
-    Dict,
     get_type_hints,
     Annotated,
     get_args,
     get_origin,
     TypeVar,
     Generic,
-    FrozenSet,
-    Mapping,
     Optional,
     cast,
     Type,
     Union,
     List,
-    Collection,
     NotRequired,
-    Iterable,
     Literal,
-    Sequence,
-    Container,
+    TYPE_CHECKING,
 )
+from collections.abc import Callable, Mapping, Collection, Iterable, Sequence, Container
+
 
-from debputy.lsp.diagnostics import LintSeverity
 from debputy.manifest_parser.base_types import FileSystemMatchRule
 from debputy.manifest_parser.exceptions import (
     ManifestParseException,
@@ -78,10 +72,10 @@ from debputy.plugin.api.spec import (
 )
 from debputy.util import _info, _warn, assume_not_none
 
-if typing.TYPE_CHECKING:
-    import lsprotocol.types as types
-else:
-    import debputy.lsprotocol.types as types
+
+if TYPE_CHECKING:
+    from debputy.lsp.diagnostics import LintSeverity
+
 
 try:
     from Levenshtein import distance
@@ -111,7 +105,7 @@ else:
     ) -> None:
         k_len = len(key)
         key_path = path[key]
-        matches: List[str] = []
+        matches: list[str] = []
         current_match_strength = 0
         for acceptable_key, attr in manifest_attributes.items():
             if abs(k_len - len(acceptable_key)) > 2:
@@ -176,10 +170,10 @@ class AttributeTypeHandler:
         description: str,
         ensure_type: Callable[[Any, AttributePath], None],
         *,
-        base_type: Optional[Type[Any]] = None,
-        mapper: Optional[
+        base_type: type[Any] | None = None,
+        mapper: None | (
             Callable[[Any, AttributePath, Optional["ParserContextData"]], Any]
-        ] = None,
+        ) = None,
     ) -> None:
         self._description = description
         self._ensure_type = ensure_type
@@ -209,9 +203,9 @@ class AttributeTypeHandler:
 
     def combine_mapper(
         self,
-        mapper: Optional[
+        mapper: None | (
             Callable[[Any, AttributePath, Optional["ParserContextData"]], Any]
-        ],
+        ),
     ) -> "AttributeTypeHandler":
         if mapper is None:
             return self
@@ -242,8 +236,8 @@ class AttributeDescription:
     target_attribute: str
     attribute_type: Any
     type_validator: AttributeTypeHandler
-    annotations: Tuple[Any, ...]
-    conflicting_attributes: FrozenSet[str]
+    annotations: tuple[Any, ...]
+    conflicting_attributes: frozenset[str]
     conditional_required: Optional["ConditionalRequired"]
     parse_hints: Optional["DetectedDebputyParseHint"] = None
     is_optional: bool = False
@@ -264,10 +258,8 @@ def _extract_path_hint(v: Any, attribute_path: AttributePath) -> bool:
 @dataclasses.dataclass(slots=True, frozen=True)
 class DeclarativeNonMappingInputParser(DeclarativeInputParser[TD], Generic[TD, SF]):
     alt_form_parser: AttributeDescription
-    inline_reference_documentation: Optional[ParserDocumentation] = None
-    expected_debputy_integration_mode: Optional[Container[DebputyIntegrationMode]] = (
-        None
-    )
+    inline_reference_documentation: ParserDocumentation | None = None
+    expected_debputy_integration_mode: Container[DebputyIntegrationMode] | None = None
 
     def parse_input(
         self,
@@ -307,19 +299,17 @@ class DeclarativeNonMappingInputParser(DeclarativeInputParser[TD], Generic[TD, S
 
 @dataclasses.dataclass(slots=True)
 class DeclarativeMappingInputParser(DeclarativeInputParser[TD], Generic[TD, SF]):
-    input_time_required_parameters: FrozenSet[str]
-    all_parameters: FrozenSet[str]
+    input_time_required_parameters: frozenset[str]
+    all_parameters: frozenset[str]
     manifest_attributes: Mapping[str, "AttributeDescription"]
     source_attributes: Mapping[str, "AttributeDescription"]
-    at_least_one_of: FrozenSet[FrozenSet[str]]
-    alt_form_parser: Optional[AttributeDescription]
-    mutually_exclusive_attributes: FrozenSet[FrozenSet[str]] = frozenset()
-    _per_attribute_conflicts_cache: Optional[Mapping[str, FrozenSet[str]]] = None
-    inline_reference_documentation: Optional[ParserDocumentation] = None
+    at_least_one_of: frozenset[frozenset[str]]
+    alt_form_parser: AttributeDescription | None
+    mutually_exclusive_attributes: frozenset[frozenset[str]] = frozenset()
+    _per_attribute_conflicts_cache: Mapping[str, frozenset[str]] | None = None
+    inline_reference_documentation: ParserDocumentation | None = None
     path_hint_source_attributes: Sequence[str] = tuple()
-    expected_debputy_integration_mode: Optional[Container[DebputyIntegrationMode]] = (
-        None
-    )
+    expected_debputy_integration_mode: Container[DebputyIntegrationMode] | None = None
 
     def _parse_alt_form(
         self,
@@ -348,7 +338,7 @@ class DeclarativeMappingInputParser(DeclarativeInputParser[TD], Generic[TD, SF])
 
     def _validate_expected_keys(
         self,
-        value: Dict[Any, Any],
+        value: dict[Any, Any],
         path: AttributePath,
         *,
         parser_context: Optional["ParserContextData"] = None,
@@ -406,7 +396,7 @@ class DeclarativeMappingInputParser(DeclarativeInputParser[TD], Generic[TD, SF])
 
     def _parse_typed_dict_form(
         self,
-        value: Dict[Any, Any],
+        value: dict[Any, Any],
         path: AttributePath,
         *,
         parser_context: Optional["ParserContextData"] = None,
@@ -477,7 +467,7 @@ class DeclarativeMappingInputParser(DeclarativeInputParser[TD], Generic[TD, SF])
             return self._parse_alt_form(value, path, parser_context=parser_context)
         return self._parse_typed_dict_form(value, path, parser_context=parser_context)
 
-    def _per_attribute_conflicts(self) -> Mapping[str, FrozenSet[str]]:
+    def _per_attribute_conflicts(self) -> Mapping[str, frozenset[str]]:
         conflicts = self._per_attribute_conflicts_cache
         if conflicts is not None:
             return conflicts
@@ -520,12 +510,12 @@ else:
 
 class ParserGenerator:
     def __init__(self) -> None:
-        self._registered_types: Dict[Any, TypeMapping[Any, Any]] = {}
-        self._object_parsers: Dict[str, DispatchingObjectParser] = {}
-        self._table_parsers: Dict[
-            Type[DebputyDispatchableType], DispatchingTableParser[Any]
+        self._registered_types: dict[Any, TypeMapping[Any, Any]] = {}
+        self._object_parsers: dict[str, DispatchingObjectParser] = {}
+        self._table_parsers: dict[
+            type[DebputyDispatchableType], DispatchingTableParser[Any]
         ] = {}
-        self._in_package_context_parser: Dict[str, Any] = {}
+        self._in_package_context_parser: dict[str, Any] = {}
 
     def register_mapped_type(self, mapped_type: TypeMapping[Any, Any]) -> None:
         existing = self._registered_types.get(mapped_type.target_type)
@@ -535,14 +525,14 @@ class ParserGenerator:
 
     def get_mapped_type_from_target_type(
         self,
-        mapped_type: Type[T],
-    ) -> Optional[TypeMapping[Any, T]]:
+        mapped_type: type[T],
+    ) -> TypeMapping[Any, T] | None:
         return self._registered_types.get(mapped_type)
 
-    def discard_mapped_type(self, mapped_type: Type[T]) -> None:
+    def discard_mapped_type(self, mapped_type: type[T]) -> None:
         del self._registered_types[mapped_type]
 
-    def add_table_parser(self, rt: Type[DebputyDispatchableType], path: str) -> None:
+    def add_table_parser(self, rt: type[DebputyDispatchableType], path: str) -> None:
         assert rt not in self._table_parsers
         self._table_parsers[rt] = DispatchingTableParser(rt, path)
 
@@ -550,11 +540,11 @@ class ParserGenerator:
         self,
         path: str,
         *,
-        parser_documentation: Optional[ParserDocumentation] = None,
-        expected_debputy_integration_mode: Optional[
+        parser_documentation: ParserDocumentation | None = None,
+        expected_debputy_integration_mode: None | (
             Container[DebputyIntegrationMode]
-        ] = None,
-        unknown_keys_diagnostic_severity: Optional[LintSeverity] = "error",
+        ) = None,
+        unknown_keys_diagnostic_severity: Optional["LintSeverity"] = "error",
         allow_unknown_keys: bool = False,
     ) -> DispatchingObjectParser:
         assert path not in self._in_package_context_parser
@@ -581,7 +571,7 @@ class ParserGenerator:
     @property
     def dispatchable_table_parsers(
         self,
-    ) -> Mapping[Type[DebputyDispatchableType], DispatchingTableParser[Any]]:
+    ) -> Mapping[type[DebputyDispatchableType], DispatchingTableParser[Any]]:
         return self._table_parsers
 
     @property
@@ -590,24 +580,24 @@ class ParserGenerator:
 
     def dispatch_parser_table_for(
         self, rule_type: TTP
-    ) -> Optional[DispatchingTableParser[TP]]:
+    ) -> DispatchingTableParser[TP] | None:
         return cast(
             "Optional[DispatchingTableParser[TP]]", self._table_parsers.get(rule_type)
         )
 
     def generate_parser(
         self,
-        parsed_content: Type[TD],
+        parsed_content: type[TD],
         *,
-        source_content: Optional[SF] = None,
+        source_content: SF | None = None,
         allow_optional: bool = False,
-        inline_reference_documentation: Optional[ParserDocumentation] = None,
-        expected_debputy_integration_mode: Optional[
+        inline_reference_documentation: ParserDocumentation | None = None,
+        expected_debputy_integration_mode: None | (
             Container[DebputyIntegrationMode]
-        ] = None,
-        automatic_docs: Optional[
-            Mapping[Type[Any], Sequence[StandardParserAttributeDocumentation]]
-        ] = None,
+        ) = None,
+        automatic_docs: None | (
+            Mapping[type[Any], Sequence[StandardParserAttributeDocumentation]]
+        ) = None,
     ) -> DeclarativeInputParser[TD]:
         """Derive a parser from a TypedDict
 
@@ -828,8 +818,8 @@ class ParserGenerator:
 
         sources = collections.defaultdict(set)
         seen_targets = set()
-        seen_source_names: Dict[str, str] = {}
-        source_attributes: Dict[str, AttributeDescription] = {}
+        seen_source_names: dict[str, str] = {}
+        source_attributes: dict[str, AttributeDescription] = {}
         path_hint_source_attributes = []
 
         for k in source_content_attributes:
@@ -866,7 +856,7 @@ class ParserGenerator:
                 ia.type_validator = ia.type_validator.combine_mapper(bridge_mapper)
             source_attributes[k] = ia
 
-        def _as_attr_names(td_name: Iterable[str]) -> FrozenSet[str]:
+        def _as_attr_names(td_name: Iterable[str]) -> frozenset[str]:
             return frozenset(
                 source_content_attributes[a].source_attribute_name for a in td_name
             )
@@ -1060,8 +1050,8 @@ class ParserGenerator:
             def _validator(v: Any, path: AttributePath) -> None:
                 if not isinstance(v, list):
                     _validation_type_error(path, "The attribute must be a list")
-                for i, v in enumerate(v):
-                    key_mapper.ensure_type(v, path[i])
+                for i, list_item in enumerate(v):
+                    key_mapper.ensure_type(list_item, path[i])
 
             list_mapper = (
                 map_each_element(key_mapper.mapper)
@@ -1119,11 +1109,11 @@ class ParserGenerator:
                     " Better typing may come later"
                 )
 
-            def _validator(uv: Any, path: AttributePath) -> None:
-                if not isinstance(uv, dict):
+            def _validator(v: Any, path: AttributePath) -> None:
+                if not isinstance(v, dict):
                     _validation_type_error(path, "The attribute must be a mapping")
                 key_name = "the first key in the mapping"
-                for i, (k, v) in enumerate(uv.items()):
+                for i, (k, value) in enumerate(v.items()):
                     if not key_mapper.base_type_match(k):
                         kp = path.copy_with_path_hint(key_name)
                         _validation_type_error(
@@ -1131,7 +1121,7 @@ class ParserGenerator:
                             f'The key number {i + 1} in attribute "{kp}" must be a {key_mapper.describe_type()}',
                         )
                     key_name = f"the key after {k}"
-                    value_mapper.ensure_type(v, path[k])
+                    value_mapper.ensure_type(value, path[k])
 
             return AttributeTypeHandler(
                 f"Mapping of {value_mapper.describe_type()}",
@@ -1139,7 +1129,7 @@ class ParserGenerator:
                 base_type=dict,
                 mapper=type_normalizer,
             ).combine_mapper(key_mapper.mapper)
-        if t_unmapped_orig == Union:
+        if t_unmapped_orig in (Union, UnionType):
             if _is_two_arg_x_list_x(t_provided_args):
                 # Force the order to be "X, List[X]" as it simplifies the code
                 x_list_x = (
@@ -1245,11 +1235,11 @@ class ParserGenerator:
 
     def _parse_types(
         self,
-        spec: Type[TypedDict],
+        spec: type[TypedDict],
         allow_target_attribute_annotation: bool = False,
         allow_source_attribute_annotations: bool = False,
         forbid_optional: bool = True,
-    ) -> Dict[str, AttributeDescription]:
+    ) -> dict[str, AttributeDescription]:
         annotations = get_type_hints(spec, include_extras=True)
         return {
             k: self._attribute_description(
@@ -1301,7 +1291,7 @@ class ParserGenerator:
     def _parse_alt_form(
         self,
         alt_form,
-        default_target_attribute: Optional[str],
+        default_target_attribute: str | None,
     ) -> AttributeDescription:
         td, anno, is_optional = _parse_type(
             "source_format alternative form",
@@ -1339,7 +1329,7 @@ class ParserGenerator:
         input_type: Any,
         target_type: Any,
         parsing_typed_dict_attribute: bool,
-    ) -> Optional[Callable[[Any, AttributePath, Optional["ParserContextData"]], Any]]:
+    ) -> Callable[[Any, AttributePath, Optional["ParserContextData"]], Any] | None:
         _, input_orig, input_args = unpack_type(
             input_type, parsing_typed_dict_attribute
         )
@@ -1347,17 +1337,17 @@ class ParserGenerator:
             target_type, parsing_typed_dict_attribute
         )
 
-        if input_orig != Union or not input_args:
+        if input_orig not in (Union, UnionType) or not input_args:
             raise ValueError("input_type must be a Union[...] with non-empty args")
 
         # Currently, we only support Union[X, List[X]] -> List[Y] narrowing or Union[X, List[X]] -> Union[Y, Union[Y]]
         # - Where X = Y or there is a simple standard transformation from X to Y.
 
-        if target_orig not in (Union, list) or not target_args:
+        if target_orig not in (Union, UnionType, list) or not target_args:
             # Not supported
             return None
 
-        if target_orig == Union and set(input_args) == set(target_args):
+        if target_orig in (Union, UnionType) and set(input_args) == set(target_args):
             # Not needed (identity mapping)
             return None
 
@@ -1371,12 +1361,15 @@ class ParserGenerator:
         )
         acceptable_types = {
             target_arg,
+            list[target_arg],  # type: ignore
             List[target_arg],  # type: ignore
             simplified_type,
+            list[simplified_type],  # type: ignore
             List[simplified_type],  # type: ignore
         }
         target_format = (
             target_arg,
+            list[target_arg],  # type: ignore
             List[target_arg],  # type: ignore
         )
         in_target_format = 0
@@ -1400,11 +1393,11 @@ class ParserGenerator:
             # Union[X, List[X]] -> List[Y]
 
             def _mapper_x_list_y(
-                x: Union[Any, List[Any]],
+                x: Any | list[Any],
                 ap: AttributePath,
                 pc: Optional["ParserContextData"],
-            ) -> List[Any]:
-                in_list_form: List[Any] = normalize_into_list(x, ap, pc)
+            ) -> list[Any]:
+                in_list_form: list[Any] = normalize_into_list(x, ap, pc)
 
                 return [mapped.mapper(x, ap, pc) for x in in_list_form]
 
@@ -1419,11 +1412,11 @@ class ParserGenerator:
             )
 
         def _mapper_mixed_list_y(
-            x: Union[Any, List[Any]],
+            x: Any | list[Any],
             ap: AttributePath,
             pc: Optional["ParserContextData"],
-        ) -> List[Any]:
-            in_list_form: List[Any] = normalize_into_list(x, ap, pc)
+        ) -> list[Any]:
+            in_list_form: list[Any] = normalize_into_list(x, ap, pc)
 
             return [
                 x if isinstance(x, target_arg) else mapped.mapper(x, ap, pc)
@@ -1438,7 +1431,7 @@ class ParserGenerator:
         input_type: Any,
         target_type: Any,
         parsing_typed_dict_attribute: bool,
-    ) -> Optional[Callable[[Any, AttributePath, Optional["ParserContextData"]], Any]]:
+    ) -> Callable[[Any, AttributePath, Optional["ParserContextData"]], Any] | None:
         if input_type == target_type:
             return None
         _, input_orig, input_args = unpack_type(
@@ -1448,7 +1441,7 @@ class ParserGenerator:
             target_type,
             parsing_typed_dict_attribute,
         )
-        if input_orig == Union:
+        if input_orig in (Union, UnionType):
             result = self._union_narrowing(
                 input_type, target_type, parsing_typed_dict_attribute
             )
@@ -1495,8 +1488,8 @@ class ParserGenerator:
             arg = args[0]
             m = self._registered_types.get(arg)
             if m:
-                return List[m.source_type]  # type: ignore
-        if v == Union:
+                return list[m.source_type]  # type: ignore
+        if v in (Union, UnionType):
             stripped_args = tuple(
                 self._strip_mapped_types(x, parsing_typed_dict_attribute) for x in args
             )
@@ -1511,12 +1504,12 @@ def _sort_key(attr: StandardParserAttributeDocumentation) -> Any:
 
 
 def _apply_std_docs(
-    std_doc_table: Optional[
-        Mapping[Type[Any], Sequence[StandardParserAttributeDocumentation]]
-    ],
-    source_format_typed_dict: Type[Any],
-    attribute_docs: Optional[Sequence[ParserAttributeDocumentation]],
-) -> Optional[Sequence[ParserAttributeDocumentation]]:
+    std_doc_table: (
+        Mapping[type[Any], Sequence[StandardParserAttributeDocumentation]] | None
+    ),
+    source_format_typed_dict: type[Any],
+    attribute_docs: Sequence[ParserAttributeDocumentation] | None,
+) -> Sequence[ParserAttributeDocumentation] | None:
     if std_doc_table is None or not std_doc_table:
         return attribute_docs
 
@@ -1558,15 +1551,15 @@ def _apply_std_docs(
 
 
 def _verify_and_auto_correct_inline_reference_documentation(
-    parsed_content: Type[TD],
-    source_typed_dict: Type[Any],
+    parsed_content: type[TD],
+    source_typed_dict: type[Any],
     source_content_attributes: Mapping[str, AttributeDescription],
-    inline_reference_documentation: Optional[ParserDocumentation],
+    inline_reference_documentation: ParserDocumentation | None,
     has_alt_form: bool,
-    automatic_docs: Optional[
-        Mapping[Type[Any], Sequence[StandardParserAttributeDocumentation]]
-    ] = None,
-) -> Optional[ParserDocumentation]:
+    automatic_docs: (
+        Mapping[type[Any], Sequence[StandardParserAttributeDocumentation]] | None
+    ) = None,
+) -> ParserDocumentation | None:
     orig_attribute_docs = (
         inline_reference_documentation.attribute_doc
         if inline_reference_documentation
@@ -1635,9 +1628,9 @@ def _verify_and_auto_correct_inline_reference_documentation(
 
 
 def _check_conflicts(
-    input_content_attributes: Dict[str, AttributeDescription],
-    required_attributes: FrozenSet[str],
-    all_attributes: FrozenSet[str],
+    input_content_attributes: dict[str, AttributeDescription],
+    required_attributes: frozenset[str],
+    all_attributes: frozenset[str],
 ) -> None:
     for attr_name, attr in input_content_attributes.items():
         if attr_name in required_attributes and attr.conflicting_attributes:
@@ -1667,9 +1660,9 @@ def _check_conflicts(
 
 
 def _check_attributes(
-    content: Type[TypedDict],
-    input_content: Type[TypedDict],
-    input_content_attributes: Dict[str, AttributeDescription],
+    content: type[TypedDict],
+    input_content: type[TypedDict],
+    input_content_attributes: dict[str, AttributeDescription],
     sources: Mapping[str, Collection[str]],
 ) -> None:
     target_required_keys = content.__required_keys__
@@ -1709,7 +1702,7 @@ def _validation_type_error(path: AttributePath, message: str) -> None:
     )
 
 
-def _is_two_arg_x_list_x(t_args: Tuple[Any, ...]) -> bool:
+def _is_two_arg_x_list_x(t_args: tuple[Any, ...]) -> bool:
     if len(t_args) != 2:
         return False
     lhs, rhs = t_args
@@ -1728,8 +1721,8 @@ def _is_two_arg_x_list_x(t_args: Tuple[Any, ...]) -> bool:
 
 def _extract_typed_dict(
     base_type,
-    default_target_attribute: Optional[str],
-) -> Tuple[Optional[Type[TypedDict]], Any]:
+    default_target_attribute: str | None,
+) -> tuple[type[TypedDict] | None, Any]:
     if is_typeddict(base_type):
         return base_type, None
     _, origin, args = unpack_type(base_type, False)
@@ -1789,7 +1782,7 @@ def _extract_typed_dict(
 
 
 def _dispatch_parse_generator(
-    dispatch_type: Type[DebputyDispatchableType],
+    dispatch_type: type[DebputyDispatchableType],
 ) -> Callable[[Any, AttributePath, Optional["ParserContextData"]], Any]:
     def _dispatch_parse(
         value: Any,
@@ -1806,7 +1799,7 @@ def _dispatch_parse_generator(
 
 
 def _dispatch_parser(
-    dispatch_type: Type[DebputyDispatchableType],
+    dispatch_type: type[DebputyDispatchableType],
 ) -> AttributeTypeHandler:
     return AttributeTypeHandler(
         dispatch_type.__name__,
@@ -1820,9 +1813,9 @@ def _parse_type(
     orig_td: Any,
     forbid_optional: bool = True,
     parsing_typed_dict_attribute: bool = True,
-) -> Tuple[Any, Tuple[Any, ...], bool]:
+) -> tuple[Any, tuple[Any, ...], bool]:
     td, v, args = unpack_type(orig_td, parsing_typed_dict_attribute)
-    md: Tuple[Any, ...] = tuple()
+    md: tuple[Any, ...] = tuple()
     optional = False
     if v is not None:
         if v == Annotated:
@@ -1853,19 +1846,19 @@ def _normalize_attribute_name(attribute: str) -> str:
 @dataclasses.dataclass
 class DetectedDebputyParseHint:
     target_attribute: str
-    source_manifest_attribute: Optional[str]
-    conflict_with_source_attributes: FrozenSet[str]
-    conditional_required: Optional[ConditionalRequired]
+    source_manifest_attribute: str | None
+    conflict_with_source_attributes: frozenset[str]
+    conditional_required: ConditionalRequired | None
     applicable_as_path_hint: bool
 
     @classmethod
     def parse_annotations(
         cls,
-        anno: Tuple[Any, ...],
+        anno: tuple[Any, ...],
         error_context: str,
-        default_attribute_name: Optional[str],
+        default_attribute_name: str | None,
         is_required: bool,
-        default_target_attribute: Optional[str] = None,
+        default_target_attribute: str | None = None,
         allow_target_attribute_annotation: bool = False,
         allow_source_attribute_annotations: bool = False,
     ) -> "DetectedDebputyParseHint":
@@ -1914,7 +1907,7 @@ class DetectedDebputyParseHint:
         if conditional_required and is_required:
             if default_attribute_name is None:
                 raise ValueError(
-                    f"is_required cannot be True without default_attribute_name being not None"
+                    "is_required cannot be True without default_attribute_name being not None"
                 )
             raise ValueError(
                 f'The attribute "{default_attribute_name}" is Required while also being conditionally required.'
@@ -1936,7 +1929,7 @@ class DetectedDebputyParseHint:
 def _source_attribute_allowed(
     source_attribute_allowed: bool,
     error_context: str,
-    annotation: Optional[DebputyParseHint],
+    annotation: DebputyParseHint | None,
 ) -> None:
     if source_attribute_allowed or annotation is None:
         return
