@@ -3,7 +3,6 @@ import os
 import subprocess
 from collections.abc import Sequence
 
-from debputy import DEBPUTY_ROOT_DIR
 from debputy.commands.debputy_cmd.context import CommandContext
 from debputy.deb_packaging_support import setup_control_files
 from debputy.filesystem_scan import FSRootDir
@@ -18,6 +17,7 @@ from debputy.util import (
     ensure_dir,
     _info,
 )
+from debputy.version import DEBPUTY_ROOT_DIR
 
 _RRR_DEB_ASSEMBLY_KEYWORD = "debputy/deb-assembly"
 _NOTIFIED_ABOUT_FALLBACK_ASSEMBLY = False
