@@ -5,7 +5,6 @@ from importlib.resources.abc import Traversable
 from pathlib import Path
 from typing import (
     Optional,
-    Generic,
     TYPE_CHECKING,
     TypeVar,
     cast,
@@ -58,7 +57,11 @@ from debputy.plugin.plugin_state import (
     run_in_context_of_plugin,
 )
 from debputy.substitution import VariableContext
-from debputy.util import _normalize_path, package_cross_check_precheck
+from debputy.util import (
+    _normalize_path,
+    package_cross_check_precheck,
+    PackageTypeSelector,
+)
 
 if TYPE_CHECKING:
     from debputy.lsp.diagnostics import LintSeverity
@@ -74,10 +77,11 @@ if TYPE_CHECKING:
     )
     from debputy.plugins.debputy.to_be_api_types import (
         BuildRuleParsedFormat,
+        BuildSystemRule,
     )
 
 
-TD = TypeVar("TD", bound="Union[DebputyParsedContent, List[DebputyParsedContent]]")
+TD = TypeVar("TD", bound=DebputyParsedContent | list[DebputyParsedContent])
 PF = TypeVar("PF")
 SF = TypeVar("SF")
 TP = TypeVar("TP")
@@ -148,16 +152,16 @@ class DebputyPluginMetadata:
 
 
 @dataclasses.dataclass(slots=True, frozen=True)
-class PluginProvidedParser(Generic[PF, TP]):
+class PluginProvidedParser[PF, TP]:
     parser: "DeclarativeInputParser[PF]"
-    handler: Callable[[str, PF, "AttributePath", "ParserContextData"], TP]
+    handler: Callable[[str, PF, AttributePath, "ParserContextData"], TP]
     plugin_metadata: DebputyPluginMetadata
 
     def parse(
         self,
         name: str,
         value: object,
-        attribute_path: "AttributePath",
+        attribute_path: AttributePath,
         *,
         parser_context: "ParserContextData",
     ) -> TP:
@@ -247,7 +251,7 @@ class MetadataOrMaintscriptDetector:
     plugin_metadata: DebputyPluginMetadata
     detector_id: str
     detector: MetadataAutoDetector
-    applies_to_package_types: frozenset[str]
+    applies_to_package_types: PackageTypeSelector
     enabled: bool = True
 
     def applies_to(self, binary_package: BinaryPackage) -> bool:
@@ -276,7 +280,7 @@ class MetadataOrMaintscriptDetector:
             )
 
 
-class DeclarativeInputParser(Generic[TD]):
+class DeclarativeInputParser[TD]:
     @property
     def inline_reference_documentation(self) -> ParserDocumentation | None:
         return None
@@ -295,7 +299,7 @@ class DeclarativeInputParser(Generic[TD]):
     def parse_input(
         self,
         value: object,
-        path: "AttributePath",
+        path: AttributePath,
         *,
         parser_context: Optional["ParserContextData"] = None,
     ) -> TD:
@@ -350,7 +354,7 @@ class ListWrappedDeclarativeInputParser(DelegatingDeclarativeInputParser[TD]):
     def parse_input(
         self,
         value: object,
-        path: "AttributePath",
+        path: AttributePath,
         *,
         parser_context: Optional["ParserContextData"] = None,
     ) -> TD:
@@ -376,7 +380,7 @@ class ListWrappedDeclarativeInputParser(DelegatingDeclarativeInputParser[TD]):
         return result
 
 
-class DispatchingParserBase(Generic[TP]):
+class DispatchingParserBase[TP]:
     def __init__(self, manifest_attribute_path_template: str) -> None:
         self.manifest_attribute_path_template = manifest_attribute_path_template
         self._parsers: dict[str, PluginProvidedParser[Any, TP]] = {}
@@ -440,7 +444,7 @@ class DispatchingParserBase(Generic[TP]):
         self,
         keyword: str | list[str],
         parser: "DeclarativeInputParser[PF]",
-        handler: Callable[[str, PF, "AttributePath", "ParserContextData"], TP],
+        handler: Callable[[str, PF, AttributePath, "ParserContextData"], TP],
         plugin_metadata: DebputyPluginMetadata,
     ) -> None:
         p = PluginProvidedParser(
@@ -453,7 +457,7 @@ class DispatchingParserBase(Generic[TP]):
     def _add_parser(
         self,
         keyword: str | Iterable[str],
-        ppp: "PluginProvidedParser[PF, TP]",
+        ppp: PluginProvidedParser[PF, TP],
     ) -> None:
         ks = [keyword] if isinstance(keyword, str) else keyword
         for k in ks:
@@ -471,13 +475,13 @@ class DispatchingParserBase(Generic[TP]):
                 )
             self._new_parser(k, ppp)
 
-    def _new_parser(self, keyword: str, ppp: "PluginProvidedParser[PF, TP]") -> None:
+    def _new_parser(self, keyword: str, ppp: PluginProvidedParser[PF, TP]) -> None:
         self._parsers[keyword] = ppp
 
     def parse_input(
         self,
         orig_value: object,
-        attribute_path: "AttributePath",
+        attribute_path: AttributePath,
         *,
         parser_context: "ParserContextData",
     ) -> TP:
@@ -532,7 +536,7 @@ class DispatchingObjectParser(
             reference_documentation_url=self.reference_documentation_url,
         )
 
-    def _new_parser(self, keyword: str, ppp: "PluginProvidedParser[PF, TP]") -> None:
+    def _new_parser(self, keyword: str, ppp: PluginProvidedParser[PF, TP]) -> None:
         super()._new_parser(keyword, ppp)
         doc = ppp.parser.inline_reference_documentation
         if doc is None or doc.description is None:
@@ -581,7 +585,7 @@ class DispatchingObjectParser(
     def parse_input(
         self,
         orig_value: object,
-        attribute_path: "AttributePath",
+        attribute_path: AttributePath,
         *,
         parser_context: "ParserContextData",
     ) -> TP:
@@ -647,7 +651,7 @@ class DispatchingObjectParser(
 
 
 @dataclasses.dataclass(slots=True, frozen=True)
-class PackageContextData(Generic[TP]):
+class PackageContextData[TP]:
     resolved_package_name: str
     value: TP
 
@@ -671,7 +675,7 @@ class InPackageContextParser(
     def parse_input(
         self,
         orig_value: object,
-        attribute_path: "AttributePath",
+        attribute_path: AttributePath,
         *,
         parser_context: Optional["ParserContextData"] = None,
     ) -> TP:
@@ -729,7 +733,7 @@ class DispatchingTableParser(
     def parse_input(
         self,
         orig_value: object,
-        attribute_path: "AttributePath",
+        attribute_path: AttributePath,
         *,
         parser_context: "ParserContextData",
     ) -> TP:
@@ -772,7 +776,7 @@ class DeclarativeValuelessKeywordInputParser(DeclarativeInputParser[None]):
     def parse_input(
         self,
         value: object,
-        path: "AttributePath",
+        path: AttributePath,
         *,
         parser_context: Optional["ParserContextData"] = None,
     ) -> TD:
@@ -897,7 +901,7 @@ def automatic_discard_rule_example(
 @dataclasses.dataclass(slots=True, frozen=True)
 class PluginProvidedPackageProcessor:
     processor_id: str
-    applies_to_package_types: frozenset[str]
+    applies_to_package_types: PackageTypeSelector
     package_processor: PackageProcessor
     dependencies: frozenset[tuple[str, str]]
     plugin_metadata: DebputyPluginMetadata
@@ -1178,7 +1182,7 @@ class PluginProvidedTypeMapping:
 
 
 @dataclasses.dataclass(slots=True, frozen=True)
-class PluginProvidedBuildSystemAutoDetection(Generic[BSR]):
+class PluginProvidedBuildSystemAutoDetection[BSR]:
     manifest_keyword: str
     build_system_rule_type: type[BSR]
     detector: BuildSystemAutoDetector
