@@ -6,7 +6,6 @@ import textwrap
 from typing import (
     Optional,
     Literal,
-    Union,
     overload,
     TypeVar,
     Any,
@@ -37,6 +36,7 @@ from debputy.manifest_parser.tagging_types import DebputyDispatchableType
 from debputy.manifest_parser.util import parse_symbolic_mode
 from debputy.packages import BinaryPackage, SourcePackage
 from debputy.types import S
+from debputy.util import PackageTypeSelector
 
 if TYPE_CHECKING:
     from debputy.manifest_parser.base_types import (
@@ -48,10 +48,6 @@ if TYPE_CHECKING:
     from debputy.plugins.debputy.to_be_api_types import BuildSystemRule
     from debputy.plugin.api.impl import DebputyPluginInitializerProvider
 
-    # Work around it being "unused" since `cast("...", ...)` does not register as a use
-    # for most static analysis tools.
-    assert DebputyPluginInitializerProvider
-
 
 DP = TypeVar("DP", bound=DebputyDispatchableType)
 
@@ -70,7 +66,7 @@ DpkgTriggerType = Literal[
     "interest-noawait",
 ]
 Maintscript = Literal["postinst", "preinst", "prerm", "postrm"]
-PackageTypeSelector = Union[Literal["deb", "udeb"], Iterable[Literal["deb", "udeb"]]]
+
 ServiceUpgradeRule = Literal[
     "do-nothing",
     "reload",
@@ -432,7 +428,7 @@ class DebputyPluginDefinition:
         func: MetadataAutoDetector | None = None,
         *,
         detector_id: str | None = None,
-        package_type: PackageTypeSelector = "deb",
+        package_types: PackageTypeSelector = PackageTypeSelector.DEB,
     ) -> Callable[[MetadataAutoDetector], MetadataAutoDetector] | MetadataAutoDetector:
         """Provide a pre-assembly hook that can affect the metadata/maintscript of binary ("deb") packages
 
@@ -473,7 +469,7 @@ class DebputyPluginDefinition:
         :param func: The function to be decorated/registered.
         :param detector_id: A plugin-wide unique ID for this detector. Packagers may use this ID for disabling
           the detector and accordingly the ID is part of the plugin's API toward the packager.
-        :param package_type: Which kind of packages this metadata detector applies to.  The package type is generally
+        :param package_types: Which kind of packages this metadata detector applies to.  The package type is generally
           defined by `Package-Type` field in the binary package. The default is to only run for regular `deb` packages
           and ignore `udeb` packages.
         """
@@ -486,7 +482,7 @@ class DebputyPluginDefinition:
                 api.metadata_or_maintscript_detector(
                     final_id,
                     f,
-                    package_type=package_type,
+                    package_types=package_types,
                 )
 
             self._generic_initializers.append(_init)
@@ -758,7 +754,7 @@ class DebputyPluginInitializer:
         auto_detector_id: str,
         auto_detector: MetadataAutoDetector,
         *,
-        package_type: PackageTypeSelector = "deb",
+        package_types: PackageTypeSelector = PackageTypeSelector.DEB,
     ) -> None:
         """Provide a pre-assembly hook that can affect the metadata/maintscript of binary ("deb") packages
 
@@ -781,7 +777,7 @@ class DebputyPluginInitializer:
           the detector and accordingly the ID is part of the plugin's API toward the packager.
         :param auto_detector: The code to be called that will be run at the metadata generation state (once for each
           binary package).
-        :param package_type: Which kind of packages this metadata detector applies to.  The package type is generally
+        :param package_types: Which kind of packages this metadata detector applies to.  The package type is generally
           defined by `Package-Type` field in the binary package. The default is to only run for regular `deb` packages
           and ignore `udeb` packages.
         """
@@ -1259,30 +1255,13 @@ class VirtualPath:
         """
         raise NotImplementedError
 
-    def stat(self) -> os.stat_result:
-        """Attempt to do stat of the underlying path (if it exists)
-
-        *Avoid* using `stat()` whenever possible where a more specialized attribute exist.  The
-        `stat()` call returns the data from the file system and often, `debputy` does *not* track
-        its state in the file system.  As an example, if you want to know the file system mode of
-        a path, please use the `mode` attribute instead.
-
-        This never follow symlinks (it behaves like `os.lstat`). It will raise an error
-        if the path is not backed by a file system object (that is, `has_fs_path` is False).
-
-        :return: The stat result or an error.
-        """
-        raise NotImplementedError()
-
     @property
     def size(self) -> int:
         """Resolve the file size (`st_size`)
 
-        This may be using `stat()` and therefore `fs_path`.
-
         :return: The size of the file in bytes
         """
-        return self.stat().st_size
+        raise NotImplementedError
 
     @property
     def mode(self) -> int:
@@ -1421,20 +1400,7 @@ class VirtualPath:
         buffering: int = -1,
     ) -> BinaryIO: ...
 
-    @overload
-    def open(
-        self,
-        *,
-        byte_io: bool,
-        buffering: int = -1,
-    ) -> TextIO | BinaryIO: ...
-
-    def open(
-        self,
-        *,
-        byte_io: bool = False,
-        buffering: int = -1,
-    ) -> TextIO | BinaryIO:
+    def open(self, *, byte_io=False, buffering=-1):
         """Open the file for reading.  Usually used with a context manager
 
         By default, the file is opened in text mode (utf-8). Binary mode can be requested
