@@ -4,6 +4,7 @@ import re
 import textwrap
 from typing import (
     Any,
+    Iterator,
     NotRequired,
     Union,
     Literal,
@@ -46,7 +47,7 @@ from debputy.plugin.api.spec import (
     not_integrations,
 )
 from debputy.plugins.debputy.types import (
-    BuiltUsingBase,
+    BuiltUsingItem,
     BuiltUsing,
     StaticBuiltUsing,
     MatchedBuiltUsingRelation,
@@ -153,7 +154,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
         rule_name="built-using",
         parsed_format=list[BuiltUsingParsedFormat],
         handler=_parse_built_using,
-        expected_debputy_integration_mode=not_integrations("dh-sequence-zz-debputy-rrr"),
+        expected_debputy_integration_mode=not_integrations(
+            "dh-sequence-zz-debputy-rrr"
+        ),
         inline_reference_documentation=reference_documentation(
             title="Built-Using dependency relations (`$RULE_NAME`)",
             description=textwrap.dedent(
@@ -214,7 +217,9 @@ def register_binary_package_rules(api: DebputyPluginInitializerProvider) -> None
         rule_name="static-built-using",
         parsed_format=list[BuiltUsingParsedFormat],
         handler=_parse_static_built_using,
-        expected_debputy_integration_mode=not_integrations("dh-sequence-zz-debputy-rrr"),
+        expected_debputy_integration_mode=not_integrations(
+            "dh-sequence-zz-debputy-rrr"
+        ),
         inline_reference_documentation=reference_documentation(
             title="Static-Built-Using dependency relations (`$RULE_NAME`)",
             description=textwrap.dedent(
@@ -415,46 +420,50 @@ def _process_service_rules(
 
 
 def _parse_built_using(
-    name: str,
+    _name: str,
     parsed_data: list[BuiltUsingParsedFormat],
     attribute_path: AttributePath,
     parser_context: ParserContextData,
-) -> list[BuiltUsing]:
-    return _built_using_handler(
-        BuiltUsing,
-        name,
-        parsed_data,
-        attribute_path,
-        parser_context,
-    )
+) -> BuiltUsing:
+    items = _built_using_handler(parsed_data, attribute_path, parser_context)
+    return BuiltUsing(items)
 
 
 def _parse_static_built_using(
-    name: str,
+    _name: str,
     parsed_data: list[BuiltUsingParsedFormat],
     attribute_path: AttributePath,
     parser_context: ParserContextData,
-) -> list[StaticBuiltUsing]:
-    return _built_using_handler(
-        StaticBuiltUsing,
-        name,
-        parsed_data,
-        attribute_path,
-        parser_context,
-    )
+) -> StaticBuiltUsing:
+    items = _built_using_handler(parsed_data, attribute_path, parser_context)
+    return StaticBuiltUsing(items)
 
 
 _VALID_BUILT_USING_GLOB = re.compile("[a-z*][a-z0-9.+*-]*")
 _BUILT_USING_GLOB_TO_RE = str.maketrans({".": "[.]", "+": "[+]", "*": ".*"})
 
 
-def _validate_built_using[T: BuiltUsingBase](
-    cls: type[T],
+def _built_using_matches(
+    regex: re.Pattern,
+    other: Literal["Build-Depends-Arch", "Build-Depends-Indep"],
+    parser_context: ParserContextData,
+) -> Iterator[MatchedBuiltUsingRelation]:
+    """Helper for _validate_built_using."""
+    for bd_field in ("Build-Depends", other):
+        raw = parser_context.source_package.fields.get(bd_field)
+        if raw is not None:
+            for options in PkgRelation.parse_relations(raw):
+                for idx, relation in enumerate(options):
+                    if regex.fullmatch(relation["name"]) is not None:
+                        yield MatchedBuiltUsingRelation(not idx, relation)
+
+
+def _validate_built_using(
     parsed_data: BuiltUsingParsedFormat,
     attribute_path: AttributePath,
     parser_context: ParserContextData,
-) -> T:
-    # Process an item in a (static-)built-using list.
+) -> BuiltUsingItem:
+    """Helper for _built_using_handler."""
     raw_glob = parsed_data["sources_for"]
     if _VALID_BUILT_USING_GLOB.fullmatch(raw_glob) is None:
         raise ManifestParseException(
@@ -464,52 +473,32 @@ def _validate_built_using[T: BuiltUsingBase](
     regex = re.compile(raw_glob.translate(_BUILT_USING_GLOB_TO_RE))
 
     pkg = parser_context.current_binary_package_state.binary_package
+    other: Literal["Build-Depends-Arch", "Build-Depends-Indep"]
     if pkg.is_arch_all:
         other = "Build-Depends-Indep"
     else:
         other = "Build-Depends-Arch"
-    # pylint: disable=too-many-nested-blocks
-    matched_packages = []
-    for bd_field in ("Build-Depends", other):
-        raw = parser_context.source_package.fields.get(bd_field)
-        if raw is not None:
-            for options in PkgRelation.parse_relations(raw):
-                options: list[PkgRelation.ParsedRelation]
-                for idx, relation in enumerate(options):
-                    name = relation["name"]
-                    if regex.fullmatch(name):
-                        matched_packages.append(
-                            MatchedBuiltUsingRelation(name, not idx, relation)
-                        )
+    matched_packages = tuple(_built_using_matches(regex, other, parser_context))
     if not matched_packages:
         raise ManifestParseException(
-            f"The glob {raw_glob!r} defined at {attribute_path["sources_for"].path} does match at least one clause of Build-Depends or {other}."
+            f"The glob {raw_glob!r} defined at {attribute_path["sources_for"].path} matches no clause of Build-Depends or {other}."
             " Either a Build-dependency is missing or the glob fails to match the intended build-dependency, or the glob superfluous and can be removed."
         )
-    return cls(
-        raw_glob,
+    return BuiltUsingItem(
         matched_packages,
         parsed_data.get("when"),
         attribute_path,
     )
 
 
-def _built_using_handler[T: BuiltUsingBase](
-    cls: type[T],
-    _name: str,
+def _built_using_handler(
     parsed_data: list[BuiltUsingParsedFormat],
     attribute_path: AttributePath,
     parser_context: ParserContextData,
-) -> list[T]:
-    return [
-        _validate_built_using(
-            cls,
-            pd,
-            attribute_path[idx],
-            parser_context,
-        )
-        for idx, pd in enumerate(parsed_data)
-    ]
+) -> Iterator[BuiltUsingItem]:
+    """Helper for _parse_built_using and _parse_static_built_using."""
+    for idx, pd in enumerate(parsed_data):
+        yield _validate_built_using(pd, attribute_path[idx], parser_context)
 
 
 def _unpack_list(
