@@ -4,17 +4,13 @@ import enum
 import os.path
 import subprocess
 from typing import (
-    Optional,
-    FrozenSet,
     final,
     TYPE_CHECKING,
     Union,
     Annotated,
-    List,
     NotRequired,
     Literal,
     Any,
-    Type,
     TypeVar,
     Self,
     is_typeddict,
@@ -602,7 +598,6 @@ class StepBasedBuildSystemRule(BuildSystemRule):
         after this method returns. For state initialization, this can be useful if the state
         is somewhat expensive and not needed for `clean`.
         """
-        pass
 
     def configure_impl(
         self,
