@@ -1,11 +1,10 @@
 from typing import (
-    List,
     TypedDict,
     NotRequired,
     Annotated,
     Union,
-    Mapping,
 )
+from collections.abc import Mapping
 
 import pytest
 
@@ -19,20 +18,20 @@ from debputy.manifest_parser.declarative_parser import ParserGenerator
 from debputy.manifest_parser.mapper_code import type_mapper_str2package
 from debputy.manifest_parser.parser_data import ParserContextData
 from debputy.manifest_parser.util import AttributePath
-from debputy.packages import BinaryPackage
+from debputy.packages import BinaryPackage, SourcePackage
 from debputy.substitution import NULL_SUBSTITUTION
 from tutil import faked_binary_package
 
 
 class TFinalEntity(DebputyParsedContent):
-    sources: List[str]
+    sources: list[str]
     install_as: NotRequired[str]
-    into: NotRequired[List[BinaryPackage]]
+    into: NotRequired[list[BinaryPackage]]
     recursive: NotRequired[bool]
 
 
 class TSourceEntity(TypedDict):
-    sources: NotRequired[List[str]]
+    sources: NotRequired[list[str]]
     source: NotRequired[Annotated[str, DebputyParseHint.target_attribute("sources")]]
     as_: NotRequired[
         Annotated[
@@ -41,11 +40,11 @@ class TSourceEntity(TypedDict):
             DebputyParseHint.conflicts_with_source_attributes("sources"),
         ]
     ]
-    into: NotRequired[Union[BinaryPackage, List[BinaryPackage]]]
+    into: NotRequired[BinaryPackage | list[BinaryPackage]]
     recursive: NotRequired[bool]
 
 
-TSourceEntityAltFormat = Union[TSourceEntity, List[str], str]
+TSourceEntityAltFormat = Union[TSourceEntity, list[str], str]
 
 
 foo_package = faked_binary_package("foo")
@@ -63,6 +62,11 @@ context_package_states = {
 
 
 class TestParserContextData(ParserContextData):
+
+    @property
+    def source_package(self) -> SourcePackage:
+        raise NotImplementedError("Implement if the test needs it")
+
     @property
     def _package_states(self) -> Mapping[str, PackageTransformationDefinition]:
         return context_package_states
@@ -163,7 +167,7 @@ def parser_context():
             },
             {"sources": "parse-root"},
             TFinalEntity,
-            List[str],
+            list[str],
         ),
         (
             "foo",
@@ -172,7 +176,7 @@ def parser_context():
             },
             {"sources": "parse-root"},
             TFinalEntity,
-            Union[str, List[str]],
+            Union[str, list[str]],
         ),
         (
             ["foo", "bar"],
@@ -181,7 +185,7 @@ def parser_context():
             },
             {"sources": "parse-root"},
             TFinalEntity,
-            Union[str, List[str]],
+            Union[str, list[str]],
         ),
         (
             {"source": "foo", "recursive": True},
@@ -206,10 +210,7 @@ def test_declarative_parser_ok(
 ):
     pg = ParserGenerator()
     pg.register_mapped_type(TypeMapping(BinaryPackage, str, type_mapper_str2package))
-    parser = pg.generate_parser(
-        parse_content,
-        source_content=source_content,
-    )
+    parser = pg.generate_parser(parse_content, source_content=source_content)
     data_path = attribute_path["parse-root"]
     parsed_data = parser.parse_input(
         source_payload, data_path, parser_context=parser_context
